@@ -1,4 +1,4 @@
-/* $Id: bogofilter.c 6228 2005-09-04 14:49:43Z relson $ */
+/* $Id: bogofilter.c 6714 2008-04-20 15:27:06Z relson $ */
 
 /*****************************************************************************
 
@@ -85,7 +85,7 @@ rc_t bogofilter(int argc, char **argv)
 
     words = register_aft ? wordhash_new() : NULL;
 
-    bogoreader_init(argc, argv);
+    bogoreader_init(argc, (const char * const *) argv);
 
     while ((*reader_more)()) {
 	double spamicity;
