@@ -1,4 +1,4 @@
-/* $Id: bogolexer.c 6654 2007-02-26 00:25:29Z relson $ */
+/* $Id: bogolexer.c 6714 2008-04-20 15:27:06Z relson $ */
 
 /*****************************************************************************
 
@@ -161,7 +161,7 @@ static void process_arglist(int argc, char **argv)
     }
 }
 
-void process_arg(int option, const char *name, const char *val, priority_t precedence, arg_pass_t pass)
+int process_arg(int option, const char *name, const char *val, priority_t precedence, arg_pass_t pass)
 {
     pass = 0;		/* suppress compiler warning */
 
@@ -283,6 +283,8 @@ void process_arg(int option, const char *name, const char *val, priority_t prece
 	    exit(EX_ERROR);
 	}
     }
+
+    return 0;
 }
 
 static int count=0;
@@ -311,7 +313,7 @@ int main(int argc, char **argv)
 	    fprintf(fpo, "normal mode.\n");
     }
 
-    bogoreader_init(argc, argv);
+    bogoreader_init(argc, (const char * const *) argv);
 
     while ((*reader_more)()) {
 	word_t token;
