@@ -1,4 +1,4 @@
-/* $Id: bogotune.c 6654 2007-02-26 00:25:29Z relson $ */
+/* $Id: bogotune.c 6718 2008-04-26 12:51:10Z relson $ */
 
 /*****************************************************************************
 
@@ -54,6 +54,7 @@ AUTHORS:
 
 #include "bogoconfig.h"
 #include "bogoreader.h"
+#include "bool.h"
 #include "collect.h"
 #include "datastore.h"
 #include "longoptions.h"
@@ -144,7 +145,7 @@ static void *env = NULL;
 
 static bool    esf_flag = true;		/* test ESF factors if true */
 static bool    exit_zero = false;	/* non-error exits zero */
-static char   *bogolex_file = NULL;	/* non-NULL if creating msg-count output */
+static const char *bogolex_file = NULL;	/* non-NULL if creating msg-count output */
 static word_t *w_msg_count;
 
 static uint message_count;
@@ -187,16 +188,24 @@ uint test = 0;
 bool fMakeCheck = false;	/* allows quick & dirty regression testing */
 uint cMakeCheck =    50;	/* ... for 50 cycles */
 
+const char *logtag = NULL;
 const char *spam_header_place = "";
 
 /* Function Declarations */
 
-static void process_bogotune_arg(int option);
-
 /* Function Definitions */
 
 static void bt_trap(void) {}
 
+static bool get_bool(const char *name, const char *arg)
+{
+    bool b = str_to_bool(arg);
+    if (DEBUG_CONFIG(2))
+	fprintf(dbgout, "%s -> %s\n", name,
+		b ? "Yes" : "No");
+    return b;
+}
+
 static int get_cnt(double fst, double lst, double amt)
 {
     int cnt = (fabs(lst - fst) + EPS) / (fabs(amt) - EPS) + 1;
@@ -712,7 +721,7 @@ static void set_train_msg_counts(wordhash_t *wh)
 
 static void print_msgcount_entry(const char *token, uint bad, uint good)
 {
-    printf( "\"%s\" %u %u\n", token, bad, good);
+    printf("\"%s\" %u %u\n", token, bad, good);
 }
 
 static void write_msgcount_file(wordhash_t *wh)
@@ -740,7 +749,7 @@ static void write_msgcount_file(wordhash_t *wh)
     return;
 }
 
-static uint read_mailbox(char *arg, mlhead_t *msgs)
+static uint read_mailbox(const char *arg, mlhead_t *msgs)
 {
     if (verbose) {
 	printf("Reading %s\n", arg);
@@ -963,6 +972,7 @@ static int process_arglist(int argc, char **argv)
 	int option_index = 0;
 	int this_option_optind = optind ? optind : 1;
 	const char *name;
+	const char *val;
 
 	option = getopt_long(argc, argv, OPTIONS,
 			     longopts_bogotune, &option_index);
@@ -972,7 +982,8 @@ static int process_arglist(int argc, char **argv)
 
 	name = (option_index == 0) ? argv[this_option_optind] : longopts_bogotune[option_index].name;
 
-	process_bogotune_arg(option);
+	val = optarg;
+	process_arg(option, NULL, val, PR_NONE, PASS_1_CLI);
     }
 
     if (ds_flag == DS_NONE)	/* default is "wordlist on disk" */
@@ -996,10 +1007,14 @@ static int process_arglist(int argc, char **argv)
     return count;
 }
 
-static void process_bogotune_arg(int option)
+int process_arg(int option, const char *name, const char *val, priority_t precedence, arg_pass_t pass)
 {
     static int lastmode = -1;
 
+    (void) name;	/* suppress compiler warning */
+    (void) precedence; 	/* suppress compiler warning */
+    (void) pass; 	/* suppress compiler warning */
+
     if (option == 1) {
 	/* If getopt's RETURN_IN_ORDER behavior */
 	switch (lastmode) {
@@ -1015,82 +1030,107 @@ static void process_bogotune_arg(int option)
 
     switch (option) {
     case 'c':
-	read_config_file(optarg, false, false, PR_CFG_USER, longopts_bogotune);
-	/* FALLTHROUGH */
+	read_config_file(val, false, false, PR_CFG_USER, longopts_bogotune);
+	/*@fallthrough@*/
+	/* fall through to suppress reading config files */
+
     case 'C':
 	suppress_config_file = true;
 	break;
+
     case 'd':
-	ds_path = xstrdup(optarg);
+	ds_path = xstrdup(val);
 	ds_flag = (ds_flag == DS_NONE) ? DS_DSK : DS_ERR;
 	break;
+
     case 'D':
 	ds_flag = (ds_flag == DS_NONE) ? DS_RAM : DS_ERR;
 	break;
+
     case 'e':
 	exit_zero = true;
 	break;
+
     case 'E':
 	esf_flag ^= true;
 	break;
+
     case 'M':
-	bogolex_file = optarg;
+	bogolex_file = val;
 	break;
+
     case 'n':
 	lastmode = 'n';
-	filelist_add(ham_files, optarg);
+	filelist_add(ham_files, val);
 	break;
+
     case 'q':
 	quiet = true;
 	break;
+
     case 'r':
-	user_robx = atof(optarg);
+	user_robx = atof(val);
 	break;
+
     case 's':
 	lastmode = 's';
-	filelist_add(spam_files, optarg);
+	filelist_add(spam_files, val);
 	break;
+
 #ifdef	TEST
     case 't':
 	test += 1;
 	break;
 #endif
     case 'T':
-	coerced_target = atoi(optarg);
+	coerced_target = atoi(val);
 	break;
+
     case 'v':
 	verbose += 1;
 	break;
+
     case 'V':
 	print_version();
 	exit(EX_OK);
+
     case 'x':
-	if (strcmp(optarg, "MakeCheck") == 0)
+	if (strcmp(val, "MakeCheck") == 0)
 	    fMakeCheck = true;
 	else
-	    set_debug_mask( optarg );
+	    set_debug_mask(val);
 	break;
 
     case O_MAX_TOKEN_LEN:
-	max_token_len = atoi(optarg);
+	max_token_len = atoi(val);
 	break;
 
     case O_MIN_TOKEN_LEN:
-	min_token_len = atoi(optarg);
+	min_token_len = atoi(val);
 	break;
 
     case O_MAX_MULTI_TOKEN_LEN:
-	max_multi_token_len=atoi(optarg);
+	max_multi_token_len=atoi(val);
 	break;
 
     case O_MULTI_TOKEN_COUNT:
-	multi_token_count=atoi(optarg);
+	multi_token_count=atoi(val);
+	break;
+
+    case O_BLOCK_ON_SUBNETS:
+	block_on_subnets = get_bool(name, val);
+	break;
+
+    case O_REPLACE_NONASCII_CHARACTERS:
+	replace_nonascii_characters = get_bool(name, val);
 	break;
 
     default:
 	help();
 	exit(EX_ERROR);
     }
+
+    return 0;
 }
 
 static double get_robx(void)
