@@ -1,4 +1,4 @@
-/* $Id: bogoutil.c 6654 2007-02-26 00:25:29Z relson $ */
+/* $Id: bogoutil.c 6718 2008-04-26 12:51:10Z relson $ */
 
 /*****************************************************************************
 
@@ -21,6 +21,7 @@ AUTHORS:
  
 #include "getopt.h"
 
+#include "bogoconfig.h"
 #include "bogofilter.h"
 #include "bogohist.h"
 #include "bool.h"
@@ -54,10 +55,6 @@ bool  onlyprint = false;
 
 const char *spam_header_place = "";
 
-/* Function Prototypes */
-
-static int process_arg(int option, const char *name, const char *arg);
-
 /* Function Definitions */
 
 /* dummies to avoid score.o */
@@ -91,13 +88,13 @@ static int ds_dump_hook(word_t *key, dsv_t *data,
     if (replace_nonascii_characters)
 	do_replace_nonascii_characters(key->text, key->leng);
 
-    fprintf( fpo, "%.*s %lu %lu",
+    fprintf(fpo, "%.*s %lu %lu",
 	    CLAMP_INT_MAX(key->leng), key->text,
 	    (unsigned long)data->spamcount,
 	    (unsigned long)data->goodcount);
     if (data->date)
-	fprintf( fpo, " %lu", (unsigned long)data->date);
-    fprintf( fpo, "\n");
+	fprintf(fpo, " %lu", (unsigned long)data->date);
+    fprintf(fpo, "\n");
 
     fflush(stdout); /* solicit ferror flag if output is shorter than buffer */
     return ferror(stdout) ? 1 : 0;
@@ -632,7 +629,7 @@ static int process_arglist(int argc, char **argv)
  	    break;
 
 	name = (option_index == 0) ? argv[this_option_optind] : longopts_bogoutil[option_index].name;
-	count += process_arg(option, name, optarg);
+	count += process_arg(option, name, optarg, PR_NONE, PASS_1_CLI);
     }
 
     if (max_token_len != 0 && max_multi_token_len == 0) {
@@ -653,10 +650,13 @@ static int process_arglist(int argc, char **argv)
     return count;
 }
 
-static int process_arg(int option, const char *name, const char *val)
+int process_arg(int option, const char *name, const char *val, priority_t precedence, arg_pass_t pass)
 {
     int count = 0;
 
+    (void) precedence;		/* suppress compiler warning */
+    (void) pass;		/* suppress compiler warning */
+
     switch (option) {
     case '?':
 	fprintf(stderr, "Unknown option '%s'.\n", name);
@@ -805,7 +805,7 @@ static int process_arg(int option, const char *name, const char *val)
     }
 
     case 'I':
-	fpin = fopen( val, "r" );
+	fpin = fopen(val, "r");
 	if (fpin == NULL) {
 	    fprintf(stderr, "Can't read file '%s'\n", val);
 	    exit(EX_ERROR);
@@ -835,19 +835,19 @@ static int process_arg(int option, const char *name, const char *val)
 	break;
 
     case O_MAX_TOKEN_LEN:
-	max_token_len = atoi(optarg);
+	max_token_len = atoi(val);
 	break;
 
     case O_MIN_TOKEN_LEN:
-	min_token_len = atoi(optarg);
+	min_token_len = atoi(val);
 	break;
 
     case O_MAX_MULTI_TOKEN_LEN:
-	max_multi_token_len=atoi(optarg);
+	max_multi_token_len=atoi(val);
 	break;
 
     case O_MULTI_TOKEN_COUNT:
-	multi_token_count=atoi(optarg);
+	multi_token_count=atoi(val);
 	break;
 
     default:
