@@ -1,4 +1,4 @@
-/* $Id: common.h,v 1.64 2006/05/29 14:26:44 relson Exp $ */
+/* $Id: common.h 6532 2006-07-04 12:09:32Z relson $ */
 
 /*****************************************************************************
 
@@ -34,8 +34,12 @@ NAME:
 #define	Z(n) n=(byte)'\0' /* mark end of string */
 #endif
 
-/* length of token will not exceed this... */
-#define MAXTOKENLEN	30
+/* length of token between these values */
+#define MIN_TOKEN_LEN		 3	/* default value of min-token-len       */
+#define MAX_TOKEN_LEN		30	/* default value of max-token-len       */
+#define MAX_MULTI_TOKEN_LEN	30	/* default value of max-multi-token-len */
+#define	MAX_PREFIX_LEN	 	 5	/* maximum length of prefix		*/
+#define	MUL_TOKEN_CNT		 1	/* default value of multi-token-count   */
 
 typedef enum sh_e { IX_SPAM = 0, 	/* index for SPAM */
 		    IX_GOOD = 1, 	/* index for GOOD */
