@@ -1,4 +1,4 @@
-/* $Id: configfile.c 6334 2005-11-18 23:15:43Z m-a $ */
+/* $Id: configfile.c 6714 2008-04-20 15:27:06Z relson $ */
 
 /*****************************************************************************
 
@@ -84,7 +84,7 @@ bool process_config_option(const char *arg, bool warn_on_error, priority_t prece
     char *dupl;
     const char delim[] = " \t=";
 
-    while (isspace(*opt))		/* ignore leadign whitespace */
+    while (isspace(*opt))		/* ignore leading whitespace */
 	opt += 1;
 
     dupl = xstrdup(opt);
@@ -135,15 +135,14 @@ bool process_config_option_as_arg(const char *opt, const char *val, priority_t p
 	    continue;
 	if (strcmp(val, "''") == 0)
 	    val = "";
-	process_arg(option->val, opt, val, precedence, PASS_2_CFG);
+	process_arg(option->val, option->name, val, precedence, PASS_2_CFG);
 	return true;
     }
 
     return false;
 }
 
-bool read_config_file(const char *fname, bool tilde_expand, bool warn_on_error, priority_t precedence,
-	struct option *longopts)
+bool read_config_file(const char *fname, bool tilde_expand, bool warn_on_error, priority_t precedence, struct option *longopts)
 {
     bool ok = true;
     int lineno = 0;
