@@ -1,4 +1,4 @@
-/* $Id: format.h 6654 2007-02-26 00:25:29Z relson $ */
+/* $Id: format.h 6704 2008-02-24 11:33:47Z m-a $ */
 
 #ifndef FORMAT_H
 #define FORMAT_H
@@ -12,7 +12,9 @@ typedef const char *FIELD;
 extern const char *spam_header_name;
 extern const char *spam_subject_tag;
 extern const char *unsure_subject_tag;
-//extern const char *spam_header_place;
+#if 0
+extern const char *spam_header_place;
+#endif
 
 /* needed by bogoconfig.c */
 
