@@ -1,4 +1,4 @@
-/* $Id: globals.h,v 1.83 2006/06/20 22:10:41 relson Exp $ */
+/* $Id: globals.h 6659 2007-04-01 16:53:09Z m-a $ */
 
 #ifndef GLOBALS_H
 #define GLOBALS_H
@@ -122,6 +122,11 @@ extern	uint	wordlist_version;
 #define	WORDLIST_ENCODING	".ENCODING"
 extern	e_enc	encoding;
 
-extern	bool	fDie;		/* true if SIGINT or SIGTERM received */
+#ifndef HAVE_SIG_ATOMIC_T
+typedef volatile int sig_atomic_t;
+#endif
+
+extern	sig_atomic_t	fDie;	/* true if a terminating signal (such as
+				   SIGINT or SIGTERM) has been received */
 
 #endif
