@@ -1,4 +1,4 @@
-/* $Id: score.c 6491 2006-06-10 02:03:47Z relson $ */
+/* $Id: score.c 6712 2008-04-19 02:33:29Z relson $ */
 
 /*****************************************************************************
 
@@ -202,7 +202,7 @@ double msg_compute_spamicity(wordhash_t *wh, FILE *fp) /*@globals errno@*/
     size_t count = 0;
     bool need_stats = (Rtable || passthrough || (verbose > 0)) && !fBogotune;
 
-    (void) fp; 	/* quench compiler warning */
+    (void) fp;			/* suppress compiler warning */
 
     if (DEBUG_ALGORITHM(2)) fprintf(dbgout, "### msg_compute_spamicity() begins\n");
 
