@@ -1,4 +1,4 @@
-/* $Id: tunelist.h 3588 2003-11-24 05:10:45Z relson $ */
+/* $Id: tunelist.h 6714 2008-04-20 15:27:06Z relson $ */
 
 /*****************************************************************************
 
@@ -60,7 +60,7 @@ struct flitem_s {		/* file list item */
 };
 
 extern	flhead_t *filelist_new(const char *name);
-extern	void filelist_add(flhead_t *list, char *name);
+extern	void filelist_add(flhead_t *list, const char *name);
 extern	void filelist_free(flhead_t *list);
 
 /***** tunelist *****/
